@@ -2,10 +2,12 @@ package AnyEvent::Finger::Transaction;
 
 use strict;
 use warnings;
-use overload '""' => sub { shift->as_string };
+use overload
+  '""' => sub { shift->as_string },
+  bool => sub { 1 }, fallback => 1;
 
 # ABSTRACT: Simple asynchronous finger transaction
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 sub res { shift->{res} }
@@ -32,12 +34,12 @@ AnyEvent::Finger::Transaction - Simple asynchronous finger transaction
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
 This class is a container for response and request objects
-which is used when a finger request comes into 
+which is used when a finger request comes into
 L<AnyEvent::Finger::Server> server instance.  It also provides
 information about the connection (the remote, local ports and
 the remote client's address).
@@ -102,7 +104,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Graham Ollis.
+This software is copyright (c) 2012-2021 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
